dhcpv4client

package
v0.14.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 5, 2025 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package dhcpv4client is a generated package which contains definitions of structs which generate gNMI paths for a YANG schema.

This package was generated by ygnmi version: v0.14.0: (ygot: v0.34.0) using the following YANG input files:

  • models-yang/models/bgp/open-traffic-generator-bgp.yang
  • models-yang/models/bmp-server/open-traffic-generator-bmp-server.yang
  • models-yang/models/dhcp/v4client/open-traffic-generator-dhcpv4client.yang
  • models-yang/models/dhcp/v4server/open-traffic-generator-dhcpv4server.yang
  • models-yang/models/dhcp/v6client/open-traffic-generator-dhcpv6client.yang
  • models-yang/models/dhcp/v6server/open-traffic-generator-dhcpv6server.yang
  • models-yang/models/discovery/open-traffic-generator-discovery-interfaces.yang
  • models-yang/models/discovery/open-traffic-generator-discovery.yang
  • models-yang/models/flow/open-traffic-generator-flow.yang
  • models-yang/models/interface/open-traffic-generator-port.yang
  • models-yang/models/isis/open-traffic-generator-isis.yang
  • models-yang/models/lacp/open-traffic-generator-lacp.yang
  • models-yang/models/lag/open-traffic-generator-lag.yang
  • models-yang/models/lldp/open-traffic-generator-lldp.yang
  • models-yang/models/ospfv2/open-traffic-generator-ospfv2.yang
  • models-yang/models/ospfv3/open-traffic-generator-ospfv3.yang
  • models-yang/models/platform/open-traffic-generator-platform.yang
  • models-yang/models/rsvp/open-traffic-generator-rsvp.yang
  • models-yang/models/types/open-traffic-generator-types.yang

Imported modules were sourced from:

  • models-yang/models/...

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Dhcpv4ClientPath

type Dhcpv4ClientPath struct {
	*ygnmi.NodePath
}

Dhcpv4ClientPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client YANG schema element.

func (*Dhcpv4ClientPath) Counters

Counters (container): Counters of an indivdual DHCPv4 session.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "state/counters"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters"

func (*Dhcpv4ClientPath) Interface

Interface (container): Information about address learned by an indivdual DHCPv4 session.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "state/interface"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface"

func (*Dhcpv4ClientPath) Name

Name (leaf): An arbitrary name of the DHCPv4 Client determined by the OTG configuration.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "*/name"
Path from root:       "/dhcpv4-clients/dhcpv4-client/*/name"

func (*Dhcpv4ClientPath) PathOriginName added in v0.14.0

func (n *Dhcpv4ClientPath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Dhcpv4ClientPath) State

State returns a Query that can be used in gNMI operations.

type Dhcpv4ClientPathAny

type Dhcpv4ClientPathAny struct {
	*ygnmi.NodePath
}

Dhcpv4ClientPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client YANG schema element.

func (*Dhcpv4ClientPathAny) Counters

Counters (container): Counters of an indivdual DHCPv4 session.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "state/counters"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters"

func (*Dhcpv4ClientPathAny) Interface

Interface (container): Information about address learned by an indivdual DHCPv4 session.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "state/interface"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface"

func (*Dhcpv4ClientPathAny) Name

Name (leaf): An arbitrary name of the DHCPv4 Client determined by the OTG configuration.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "*/name"
Path from root:       "/dhcpv4-clients/dhcpv4-client/*/name"

func (*Dhcpv4ClientPathAny) State

State returns a Query that can be used in gNMI operations.

type Dhcpv4ClientPathMap

type Dhcpv4ClientPathMap struct {
	*ygnmi.NodePath
}

Dhcpv4ClientPathMap represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client YANG schema element.

func (*Dhcpv4ClientPathMap) PathOriginName added in v0.14.0

func (n *Dhcpv4ClientPathMap) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

type Dhcpv4ClientPathMapAny

type Dhcpv4ClientPathMapAny struct {
	*ygnmi.NodePath
}

Dhcpv4ClientPathMapAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client YANG schema element.

type Dhcpv4Client_CountersPath

type Dhcpv4Client_CountersPath struct {
	*ygnmi.NodePath
}

Dhcpv4Client_CountersPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters YANG schema element.

func (*Dhcpv4Client_CountersPath) AcksReceived

AcksReceived (leaf): Number of DHCPACKS messages received.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "acks-received"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/acks-received"

func (*Dhcpv4Client_CountersPath) DeclinesSent

DeclinesSent (leaf): Number of DHCPDECLINE messages sent.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "declines-sent"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/declines-sent"

func (*Dhcpv4Client_CountersPath) DiscoversSent

DiscoversSent (leaf): Number of DHCPDISCOVER messages sent.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "discovers-sent"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/discovers-sent"

func (*Dhcpv4Client_CountersPath) NacksReceived

NacksReceived (leaf): Number of DHCPNACKS messages received.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "nacks-received"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/nacks-received"

func (*Dhcpv4Client_CountersPath) OffersReceived

OffersReceived (leaf): Number of DHCPOFFER messages received.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "offers-received"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/offers-received"

func (*Dhcpv4Client_CountersPath) PathOriginName added in v0.14.0

func (n *Dhcpv4Client_CountersPath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Dhcpv4Client_CountersPath) ReleasesSent

ReleasesSent (leaf): Number of DHCPRELEASE messages sent.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "releases-sent"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/releases-sent"

func (*Dhcpv4Client_CountersPath) RequestsSent

RequestsSent (leaf): Number of DHCPREQUEST messages sent.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "requests-sent"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/requests-sent"

func (*Dhcpv4Client_CountersPath) State

State returns a Query that can be used in gNMI operations.

type Dhcpv4Client_CountersPathAny

type Dhcpv4Client_CountersPathAny struct {
	*ygnmi.NodePath
}

Dhcpv4Client_CountersPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters YANG schema element.

func (*Dhcpv4Client_CountersPathAny) AcksReceived

AcksReceived (leaf): Number of DHCPACKS messages received.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "acks-received"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/acks-received"

func (*Dhcpv4Client_CountersPathAny) DeclinesSent

DeclinesSent (leaf): Number of DHCPDECLINE messages sent.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "declines-sent"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/declines-sent"

func (*Dhcpv4Client_CountersPathAny) DiscoversSent

DiscoversSent (leaf): Number of DHCPDISCOVER messages sent.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "discovers-sent"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/discovers-sent"

func (*Dhcpv4Client_CountersPathAny) NacksReceived

NacksReceived (leaf): Number of DHCPNACKS messages received.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "nacks-received"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/nacks-received"

func (*Dhcpv4Client_CountersPathAny) OffersReceived

OffersReceived (leaf): Number of DHCPOFFER messages received.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "offers-received"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/offers-received"

func (*Dhcpv4Client_CountersPathAny) ReleasesSent

ReleasesSent (leaf): Number of DHCPRELEASE messages sent.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "releases-sent"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/releases-sent"

func (*Dhcpv4Client_CountersPathAny) RequestsSent

RequestsSent (leaf): Number of DHCPREQUEST messages sent.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "requests-sent"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/requests-sent"

func (*Dhcpv4Client_CountersPathAny) State

State returns a Query that can be used in gNMI operations.

type Dhcpv4Client_Counters_AcksReceivedPath

type Dhcpv4Client_Counters_AcksReceivedPath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Counters_AcksReceivedPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/acks-received YANG schema element.

func (*Dhcpv4Client_Counters_AcksReceivedPath) PathOriginName added in v0.14.0

func (n *Dhcpv4Client_Counters_AcksReceivedPath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Dhcpv4Client_Counters_AcksReceivedPath) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "acks-received"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/acks-received"

type Dhcpv4Client_Counters_AcksReceivedPathAny

type Dhcpv4Client_Counters_AcksReceivedPathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Counters_AcksReceivedPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/acks-received YANG schema element.

func (*Dhcpv4Client_Counters_AcksReceivedPathAny) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "acks-received"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/acks-received"

type Dhcpv4Client_Counters_DeclinesSentPath

type Dhcpv4Client_Counters_DeclinesSentPath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Counters_DeclinesSentPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/declines-sent YANG schema element.

func (*Dhcpv4Client_Counters_DeclinesSentPath) PathOriginName added in v0.14.0

func (n *Dhcpv4Client_Counters_DeclinesSentPath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Dhcpv4Client_Counters_DeclinesSentPath) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "declines-sent"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/declines-sent"

type Dhcpv4Client_Counters_DeclinesSentPathAny

type Dhcpv4Client_Counters_DeclinesSentPathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Counters_DeclinesSentPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/declines-sent YANG schema element.

func (*Dhcpv4Client_Counters_DeclinesSentPathAny) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "declines-sent"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/declines-sent"

type Dhcpv4Client_Counters_DiscoversSentPath

type Dhcpv4Client_Counters_DiscoversSentPath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Counters_DiscoversSentPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/discovers-sent YANG schema element.

func (*Dhcpv4Client_Counters_DiscoversSentPath) PathOriginName added in v0.14.0

func (n *Dhcpv4Client_Counters_DiscoversSentPath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Dhcpv4Client_Counters_DiscoversSentPath) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "discovers-sent"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/discovers-sent"

type Dhcpv4Client_Counters_DiscoversSentPathAny

type Dhcpv4Client_Counters_DiscoversSentPathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Counters_DiscoversSentPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/discovers-sent YANG schema element.

func (*Dhcpv4Client_Counters_DiscoversSentPathAny) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "discovers-sent"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/discovers-sent"

type Dhcpv4Client_Counters_NacksReceivedPath

type Dhcpv4Client_Counters_NacksReceivedPath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Counters_NacksReceivedPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/nacks-received YANG schema element.

func (*Dhcpv4Client_Counters_NacksReceivedPath) PathOriginName added in v0.14.0

func (n *Dhcpv4Client_Counters_NacksReceivedPath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Dhcpv4Client_Counters_NacksReceivedPath) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "nacks-received"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/nacks-received"

type Dhcpv4Client_Counters_NacksReceivedPathAny

type Dhcpv4Client_Counters_NacksReceivedPathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Counters_NacksReceivedPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/nacks-received YANG schema element.

func (*Dhcpv4Client_Counters_NacksReceivedPathAny) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "nacks-received"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/nacks-received"

type Dhcpv4Client_Counters_OffersReceivedPath

type Dhcpv4Client_Counters_OffersReceivedPath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Counters_OffersReceivedPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/offers-received YANG schema element.

func (*Dhcpv4Client_Counters_OffersReceivedPath) PathOriginName added in v0.14.0

PathOrigin returns the name of the origin for the path object.

func (*Dhcpv4Client_Counters_OffersReceivedPath) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "offers-received"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/offers-received"

type Dhcpv4Client_Counters_OffersReceivedPathAny

type Dhcpv4Client_Counters_OffersReceivedPathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Counters_OffersReceivedPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/offers-received YANG schema element.

func (*Dhcpv4Client_Counters_OffersReceivedPathAny) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "offers-received"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/offers-received"

type Dhcpv4Client_Counters_ReleasesSentPath

type Dhcpv4Client_Counters_ReleasesSentPath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Counters_ReleasesSentPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/releases-sent YANG schema element.

func (*Dhcpv4Client_Counters_ReleasesSentPath) PathOriginName added in v0.14.0

func (n *Dhcpv4Client_Counters_ReleasesSentPath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Dhcpv4Client_Counters_ReleasesSentPath) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "releases-sent"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/releases-sent"

type Dhcpv4Client_Counters_ReleasesSentPathAny

type Dhcpv4Client_Counters_ReleasesSentPathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Counters_ReleasesSentPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/releases-sent YANG schema element.

func (*Dhcpv4Client_Counters_ReleasesSentPathAny) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "releases-sent"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/releases-sent"

type Dhcpv4Client_Counters_RequestsSentPath

type Dhcpv4Client_Counters_RequestsSentPath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Counters_RequestsSentPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/requests-sent YANG schema element.

func (*Dhcpv4Client_Counters_RequestsSentPath) PathOriginName added in v0.14.0

func (n *Dhcpv4Client_Counters_RequestsSentPath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Dhcpv4Client_Counters_RequestsSentPath) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "requests-sent"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/requests-sent"

type Dhcpv4Client_Counters_RequestsSentPathAny

type Dhcpv4Client_Counters_RequestsSentPathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Counters_RequestsSentPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/requests-sent YANG schema element.

func (*Dhcpv4Client_Counters_RequestsSentPathAny) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "requests-sent"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/counters/requests-sent"

type Dhcpv4Client_InterfacePath

type Dhcpv4Client_InterfacePath struct {
	*ygnmi.NodePath
}

Dhcpv4Client_InterfacePath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface YANG schema element.

func (*Dhcpv4Client_InterfacePath) Address

Address (leaf): The IPv4 address associated with this DHCP Client session.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "address"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/address"

func (*Dhcpv4Client_InterfacePath) GatewayAddress

GatewayAddress (leaf): The Gateway address associated with the DHCP Client session.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "gateway_address"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/gateway_address"

func (*Dhcpv4Client_InterfacePath) LeaseTime

LeaseTime (leaf): The duration of the IP address lease, in seconds.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "lease_time"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/lease_time"

func (*Dhcpv4Client_InterfacePath) PathOriginName added in v0.14.0

func (n *Dhcpv4Client_InterfacePath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Dhcpv4Client_InterfacePath) PrefixLength

PrefixLength (leaf): The length of the prefix

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "prefix-length"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/prefix-length"

func (*Dhcpv4Client_InterfacePath) RebindTime

RebindTime (leaf): Time in seconds until the DHCPv4 client starts rebinding.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "rebind_time"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/rebind_time"

func (*Dhcpv4Client_InterfacePath) RenewTime

RenewTime (leaf): Time in seconds until the DHCPv4 client starts renewing the lease.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "renew_time"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/renew_time"

func (*Dhcpv4Client_InterfacePath) State

State returns a Query that can be used in gNMI operations.

type Dhcpv4Client_InterfacePathAny

type Dhcpv4Client_InterfacePathAny struct {
	*ygnmi.NodePath
}

Dhcpv4Client_InterfacePathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface YANG schema element.

func (*Dhcpv4Client_InterfacePathAny) Address

Address (leaf): The IPv4 address associated with this DHCP Client session.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "address"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/address"

func (*Dhcpv4Client_InterfacePathAny) GatewayAddress

GatewayAddress (leaf): The Gateway address associated with the DHCP Client session.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "gateway_address"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/gateway_address"

func (*Dhcpv4Client_InterfacePathAny) LeaseTime

LeaseTime (leaf): The duration of the IP address lease, in seconds.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "lease_time"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/lease_time"

func (*Dhcpv4Client_InterfacePathAny) PrefixLength

PrefixLength (leaf): The length of the prefix

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "prefix-length"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/prefix-length"

func (*Dhcpv4Client_InterfacePathAny) RebindTime

RebindTime (leaf): Time in seconds until the DHCPv4 client starts rebinding.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "rebind_time"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/rebind_time"

func (*Dhcpv4Client_InterfacePathAny) RenewTime

RenewTime (leaf): Time in seconds until the DHCPv4 client starts renewing the lease.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "renew_time"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/renew_time"

func (*Dhcpv4Client_InterfacePathAny) State

State returns a Query that can be used in gNMI operations.

type Dhcpv4Client_Interface_AddressPath

type Dhcpv4Client_Interface_AddressPath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Interface_AddressPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/address YANG schema element.

func (*Dhcpv4Client_Interface_AddressPath) PathOriginName added in v0.14.0

func (n *Dhcpv4Client_Interface_AddressPath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Dhcpv4Client_Interface_AddressPath) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "address"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/address"

type Dhcpv4Client_Interface_AddressPathAny

type Dhcpv4Client_Interface_AddressPathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Interface_AddressPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/address YANG schema element.

func (*Dhcpv4Client_Interface_AddressPathAny) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "address"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/address"

type Dhcpv4Client_Interface_GatewayAddressPath

type Dhcpv4Client_Interface_GatewayAddressPath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Interface_GatewayAddressPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/gateway_address YANG schema element.

func (*Dhcpv4Client_Interface_GatewayAddressPath) PathOriginName added in v0.14.0

PathOrigin returns the name of the origin for the path object.

func (*Dhcpv4Client_Interface_GatewayAddressPath) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "gateway_address"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/gateway_address"

type Dhcpv4Client_Interface_GatewayAddressPathAny

type Dhcpv4Client_Interface_GatewayAddressPathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Interface_GatewayAddressPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/gateway_address YANG schema element.

func (*Dhcpv4Client_Interface_GatewayAddressPathAny) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "gateway_address"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/gateway_address"

type Dhcpv4Client_Interface_LeaseTimePath

type Dhcpv4Client_Interface_LeaseTimePath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Interface_LeaseTimePath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/lease_time YANG schema element.

func (*Dhcpv4Client_Interface_LeaseTimePath) PathOriginName added in v0.14.0

func (n *Dhcpv4Client_Interface_LeaseTimePath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Dhcpv4Client_Interface_LeaseTimePath) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "lease_time"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/lease_time"

type Dhcpv4Client_Interface_LeaseTimePathAny

type Dhcpv4Client_Interface_LeaseTimePathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Interface_LeaseTimePathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/lease_time YANG schema element.

func (*Dhcpv4Client_Interface_LeaseTimePathAny) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "lease_time"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/lease_time"

type Dhcpv4Client_Interface_PrefixLengthPath

type Dhcpv4Client_Interface_PrefixLengthPath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Interface_PrefixLengthPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/prefix-length YANG schema element.

func (*Dhcpv4Client_Interface_PrefixLengthPath) PathOriginName added in v0.14.0

func (n *Dhcpv4Client_Interface_PrefixLengthPath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Dhcpv4Client_Interface_PrefixLengthPath) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "prefix-length"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/prefix-length"

type Dhcpv4Client_Interface_PrefixLengthPathAny

type Dhcpv4Client_Interface_PrefixLengthPathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Interface_PrefixLengthPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/prefix-length YANG schema element.

func (*Dhcpv4Client_Interface_PrefixLengthPathAny) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "prefix-length"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/prefix-length"

type Dhcpv4Client_Interface_RebindTimePath

type Dhcpv4Client_Interface_RebindTimePath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Interface_RebindTimePath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/rebind_time YANG schema element.

func (*Dhcpv4Client_Interface_RebindTimePath) PathOriginName added in v0.14.0

func (n *Dhcpv4Client_Interface_RebindTimePath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Dhcpv4Client_Interface_RebindTimePath) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "rebind_time"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/rebind_time"

type Dhcpv4Client_Interface_RebindTimePathAny

type Dhcpv4Client_Interface_RebindTimePathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Interface_RebindTimePathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/rebind_time YANG schema element.

func (*Dhcpv4Client_Interface_RebindTimePathAny) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "rebind_time"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/rebind_time"

type Dhcpv4Client_Interface_RenewTimePath

type Dhcpv4Client_Interface_RenewTimePath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Interface_RenewTimePath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/renew_time YANG schema element.

func (*Dhcpv4Client_Interface_RenewTimePath) PathOriginName added in v0.14.0

func (n *Dhcpv4Client_Interface_RenewTimePath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Dhcpv4Client_Interface_RenewTimePath) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "renew_time"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/renew_time"

type Dhcpv4Client_Interface_RenewTimePathAny

type Dhcpv4Client_Interface_RenewTimePathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_Interface_RenewTimePathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/renew_time YANG schema element.

func (*Dhcpv4Client_Interface_RenewTimePathAny) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "renew_time"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/interface/renew_time"

type Dhcpv4Client_NamePath

type Dhcpv4Client_NamePath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_NamePath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/name YANG schema element.

func (*Dhcpv4Client_NamePath) Config

Config returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "name"
Path from root:       ""

func (*Dhcpv4Client_NamePath) PathOriginName added in v0.14.0

func (n *Dhcpv4Client_NamePath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Dhcpv4Client_NamePath) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "state/name"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/name"

type Dhcpv4Client_NamePathAny

type Dhcpv4Client_NamePathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Dhcpv4Client_NamePathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/name YANG schema element.

func (*Dhcpv4Client_NamePathAny) Config

Config returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "name"
Path from root:       ""

func (*Dhcpv4Client_NamePathAny) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-dhcpv4client"
Instantiating module: "open-traffic-generator-dhcpv4client"
Path from parent:     "state/name"
Path from root:       "/dhcpv4-clients/dhcpv4-client/state/name"

Jump to