port

package
v0.14.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 27, 2026 License: Apache-2.0 Imports: 5 Imported by: 1

Documentation

Overview

Package port is a generated package which contains definitions of structs which generate gNMI paths for a YANG schema.

This package was generated by ygnmi version: v0.14.0: (ygot: v0.34.0) using the following YANG input files:

  • models-yang/models/bgp/open-traffic-generator-bgp.yang
  • models-yang/models/bmp-server/open-traffic-generator-bmp-server.yang
  • models-yang/models/dhcp/v4client/open-traffic-generator-dhcpv4client.yang
  • models-yang/models/dhcp/v4server/open-traffic-generator-dhcpv4server.yang
  • models-yang/models/dhcp/v6client/open-traffic-generator-dhcpv6client.yang
  • models-yang/models/dhcp/v6server/open-traffic-generator-dhcpv6server.yang
  • models-yang/models/discovery/open-traffic-generator-discovery-interfaces.yang
  • models-yang/models/discovery/open-traffic-generator-discovery.yang
  • models-yang/models/flow/open-traffic-generator-flow.yang
  • models-yang/models/interface/open-traffic-generator-port.yang
  • models-yang/models/isis/open-traffic-generator-isis.yang
  • models-yang/models/lacp/open-traffic-generator-lacp.yang
  • models-yang/models/lag/open-traffic-generator-lag.yang
  • models-yang/models/lldp/open-traffic-generator-lldp.yang
  • models-yang/models/ospfv2/open-traffic-generator-ospfv2.yang
  • models-yang/models/ospfv3/open-traffic-generator-ospfv3.yang
  • models-yang/models/platform/open-traffic-generator-platform.yang
  • models-yang/models/rsvp/open-traffic-generator-rsvp.yang
  • models-yang/models/types/open-traffic-generator-types.yang

Imported modules were sourced from:

  • models-yang/models/...

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type PortPath

type PortPath struct {
	*ygnmi.NodePath
}

PortPath represents the /open-traffic-generator-port/ports/port YANG schema element.

func (*PortPath) Counters

func (n *PortPath) Counters() *Port_CountersPath

Counters (container): Counters of an OTG port.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "state/counters"
Path from root:       "/ports/port/state/counters"

func (*PortPath) DataIntegrity added in v0.14.1

func (n *PortPath) DataIntegrity() *Port_DataIntegrityPath

DataIntegrity (container): The container for data integrity metrics. The container will be empty if options.port_options.data_integrity has not been enabled during set_config.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "state/data-integrity"
Path from root:       "/ports/port/state/data-integrity"

func (*PortPath) InRate

func (n *PortPath) InRate() *Port_InRatePath

InRate (leaf): The current receive rate of an OTG port, measured in bits per second.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "state/in-rate"
Path from root:       "/ports/port/state/in-rate"

func (*PortPath) LastChange added in v0.7.1

func (n *PortPath) LastChange() *Port_LastChangePath

LastChange (leaf): The timestamp indicates the absolute time of the last link state change of the test port (e.g., up-to-down transition).

The value is the timestamp in nanoseconds relative to the Unix Epoch (Jan 1, 1970 00:00:00 UTC).

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "state/last-change"
Path from root:       "/ports/port/state/last-change"
func (n *PortPath) Link() *Port_LinkPath

Link (leaf): The current state of an OTG port.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "state/link"
Path from root:       "/ports/port/state/link"

func (*PortPath) Name

func (n *PortPath) Name() *Port_NamePath

Name (leaf): An arbitrary name of an OTG port determined by the OTG configuration.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "*/name"
Path from root:       "/ports/port/*/name"

func (*PortPath) OutRate

func (n *PortPath) OutRate() *Port_OutRatePath

OutRate (leaf): The current transmit rate of an OTG port, measured in bits per second.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "state/out-rate"
Path from root:       "/ports/port/state/out-rate"

func (*PortPath) PathOriginName added in v0.14.0

func (n *PortPath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*PortPath) State

func (n *PortPath) State() ygnmi.SingletonQuery[*oc.Port]

State returns a Query that can be used in gNMI operations.

type PortPathAny

type PortPathAny struct {
	*ygnmi.NodePath
}

PortPathAny represents the wildcard version of the /open-traffic-generator-port/ports/port YANG schema element.

func (*PortPathAny) Counters

func (n *PortPathAny) Counters() *Port_CountersPathAny

Counters (container): Counters of an OTG port.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "state/counters"
Path from root:       "/ports/port/state/counters"

func (*PortPathAny) DataIntegrity added in v0.14.1

func (n *PortPathAny) DataIntegrity() *Port_DataIntegrityPathAny

DataIntegrity (container): The container for data integrity metrics. The container will be empty if options.port_options.data_integrity has not been enabled during set_config.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "state/data-integrity"
Path from root:       "/ports/port/state/data-integrity"

func (*PortPathAny) InRate

func (n *PortPathAny) InRate() *Port_InRatePathAny

InRate (leaf): The current receive rate of an OTG port, measured in bits per second.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "state/in-rate"
Path from root:       "/ports/port/state/in-rate"

func (*PortPathAny) LastChange added in v0.7.1

func (n *PortPathAny) LastChange() *Port_LastChangePathAny

LastChange (leaf): The timestamp indicates the absolute time of the last link state change of the test port (e.g., up-to-down transition).

The value is the timestamp in nanoseconds relative to the Unix Epoch (Jan 1, 1970 00:00:00 UTC).

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "state/last-change"
Path from root:       "/ports/port/state/last-change"
func (n *PortPathAny) Link() *Port_LinkPathAny

Link (leaf): The current state of an OTG port.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "state/link"
Path from root:       "/ports/port/state/link"

func (*PortPathAny) Name

func (n *PortPathAny) Name() *Port_NamePathAny

Name (leaf): An arbitrary name of an OTG port determined by the OTG configuration.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "*/name"
Path from root:       "/ports/port/*/name"

func (*PortPathAny) OutRate

func (n *PortPathAny) OutRate() *Port_OutRatePathAny

OutRate (leaf): The current transmit rate of an OTG port, measured in bits per second.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "state/out-rate"
Path from root:       "/ports/port/state/out-rate"

func (*PortPathAny) State

func (n *PortPathAny) State() ygnmi.WildcardQuery[*oc.Port]

State returns a Query that can be used in gNMI operations.

type PortPathMap added in v0.1.24

type PortPathMap struct {
	*ygnmi.NodePath
}

PortPathMap represents the /open-traffic-generator-port/ports/port YANG schema element.

func (*PortPathMap) PathOriginName added in v0.14.0

func (n *PortPathMap) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

type PortPathMapAny added in v0.1.24

type PortPathMapAny struct {
	*ygnmi.NodePath
}

PortPathMapAny represents the wildcard version of the /open-traffic-generator-port/ports/port YANG schema element.

type Port_CountersPath

type Port_CountersPath struct {
	*ygnmi.NodePath
}

Port_CountersPath represents the /open-traffic-generator-port/ports/port/state/counters YANG schema element.

func (*Port_CountersPath) InFrames

InFrames (leaf): The total number of packets received on the port.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "in-frames"
Path from root:       "/ports/port/state/counters/in-frames"

func (*Port_CountersPath) InOctets

InOctets (leaf): The total number of octets received on the port.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "in-octets"
Path from root:       "/ports/port/state/counters/in-octets"

func (*Port_CountersPath) OutFrames

OutFrames (leaf): The total number of packets transmitted on the port.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "out-frames"
Path from root:       "/ports/port/state/counters/out-frames"

func (*Port_CountersPath) OutOctets

OutOctets (leaf): The total number of octets transmitted on the port.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "out-octets"
Path from root:       "/ports/port/state/counters/out-octets"

func (*Port_CountersPath) PathOriginName added in v0.14.0

func (n *Port_CountersPath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Port_CountersPath) State

State returns a Query that can be used in gNMI operations.

type Port_CountersPathAny

type Port_CountersPathAny struct {
	*ygnmi.NodePath
}

Port_CountersPathAny represents the wildcard version of the /open-traffic-generator-port/ports/port/state/counters YANG schema element.

func (*Port_CountersPathAny) InFrames

InFrames (leaf): The total number of packets received on the port.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "in-frames"
Path from root:       "/ports/port/state/counters/in-frames"

func (*Port_CountersPathAny) InOctets

InOctets (leaf): The total number of octets received on the port.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "in-octets"
Path from root:       "/ports/port/state/counters/in-octets"

func (*Port_CountersPathAny) OutFrames

OutFrames (leaf): The total number of packets transmitted on the port.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "out-frames"
Path from root:       "/ports/port/state/counters/out-frames"

func (*Port_CountersPathAny) OutOctets

OutOctets (leaf): The total number of octets transmitted on the port.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "out-octets"
Path from root:       "/ports/port/state/counters/out-octets"

func (*Port_CountersPathAny) State

State returns a Query that can be used in gNMI operations.

type Port_Counters_InFramesPath

type Port_Counters_InFramesPath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Port_Counters_InFramesPath represents the /open-traffic-generator-port/ports/port/state/counters/in-frames YANG schema element.

func (*Port_Counters_InFramesPath) PathOriginName added in v0.14.0

func (n *Port_Counters_InFramesPath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Port_Counters_InFramesPath) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "in-frames"
Path from root:       "/ports/port/state/counters/in-frames"

type Port_Counters_InFramesPathAny

type Port_Counters_InFramesPathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Port_Counters_InFramesPathAny represents the wildcard version of the /open-traffic-generator-port/ports/port/state/counters/in-frames YANG schema element.

func (*Port_Counters_InFramesPathAny) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "in-frames"
Path from root:       "/ports/port/state/counters/in-frames"

type Port_Counters_InOctetsPath

type Port_Counters_InOctetsPath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Port_Counters_InOctetsPath represents the /open-traffic-generator-port/ports/port/state/counters/in-octets YANG schema element.

func (*Port_Counters_InOctetsPath) PathOriginName added in v0.14.0

func (n *Port_Counters_InOctetsPath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Port_Counters_InOctetsPath) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "in-octets"
Path from root:       "/ports/port/state/counters/in-octets"

type Port_Counters_InOctetsPathAny

type Port_Counters_InOctetsPathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Port_Counters_InOctetsPathAny represents the wildcard version of the /open-traffic-generator-port/ports/port/state/counters/in-octets YANG schema element.

func (*Port_Counters_InOctetsPathAny) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "in-octets"
Path from root:       "/ports/port/state/counters/in-octets"

type Port_Counters_OutFramesPath

type Port_Counters_OutFramesPath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Port_Counters_OutFramesPath represents the /open-traffic-generator-port/ports/port/state/counters/out-frames YANG schema element.

func (*Port_Counters_OutFramesPath) PathOriginName added in v0.14.0

func (n *Port_Counters_OutFramesPath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Port_Counters_OutFramesPath) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "out-frames"
Path from root:       "/ports/port/state/counters/out-frames"

type Port_Counters_OutFramesPathAny

type Port_Counters_OutFramesPathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Port_Counters_OutFramesPathAny represents the wildcard version of the /open-traffic-generator-port/ports/port/state/counters/out-frames YANG schema element.

func (*Port_Counters_OutFramesPathAny) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "out-frames"
Path from root:       "/ports/port/state/counters/out-frames"

type Port_Counters_OutOctetsPath

type Port_Counters_OutOctetsPath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Port_Counters_OutOctetsPath represents the /open-traffic-generator-port/ports/port/state/counters/out-octets YANG schema element.

func (*Port_Counters_OutOctetsPath) PathOriginName added in v0.14.0

func (n *Port_Counters_OutOctetsPath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Port_Counters_OutOctetsPath) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "out-octets"
Path from root:       "/ports/port/state/counters/out-octets"

type Port_Counters_OutOctetsPathAny

type Port_Counters_OutOctetsPathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Port_Counters_OutOctetsPathAny represents the wildcard version of the /open-traffic-generator-port/ports/port/state/counters/out-octets YANG schema element.

func (*Port_Counters_OutOctetsPathAny) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "out-octets"
Path from root:       "/ports/port/state/counters/out-octets"

type Port_DataIntegrityPath added in v0.14.1

type Port_DataIntegrityPath struct {
	*ygnmi.NodePath
}

Port_DataIntegrityPath represents the /open-traffic-generator-port/ports/port/state/data-integrity YANG schema element.

func (*Port_DataIntegrityPath) InErrorFrames added in v0.14.1

InErrorFrames (leaf): The total number of data integrity enabled frames received with payload modified.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "in-error-frames"
Path from root:       "/ports/port/state/data-integrity/in-error-frames"

func (*Port_DataIntegrityPath) InTotalFrames added in v0.14.1

InTotalFrames (leaf): The total number of data integrity enabled frames received.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "in-total-frames"
Path from root:       "/ports/port/state/data-integrity/in-total-frames"

func (*Port_DataIntegrityPath) PathOriginName added in v0.14.1

func (n *Port_DataIntegrityPath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Port_DataIntegrityPath) State added in v0.14.1

State returns a Query that can be used in gNMI operations.

type Port_DataIntegrityPathAny added in v0.14.1

type Port_DataIntegrityPathAny struct {
	*ygnmi.NodePath
}

Port_DataIntegrityPathAny represents the wildcard version of the /open-traffic-generator-port/ports/port/state/data-integrity YANG schema element.

func (*Port_DataIntegrityPathAny) InErrorFrames added in v0.14.1

InErrorFrames (leaf): The total number of data integrity enabled frames received with payload modified.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "in-error-frames"
Path from root:       "/ports/port/state/data-integrity/in-error-frames"

func (*Port_DataIntegrityPathAny) InTotalFrames added in v0.14.1

InTotalFrames (leaf): The total number of data integrity enabled frames received.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "in-total-frames"
Path from root:       "/ports/port/state/data-integrity/in-total-frames"

func (*Port_DataIntegrityPathAny) State added in v0.14.1

State returns a Query that can be used in gNMI operations.

type Port_DataIntegrity_InErrorFramesPath added in v0.14.1

type Port_DataIntegrity_InErrorFramesPath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Port_DataIntegrity_InErrorFramesPath represents the /open-traffic-generator-port/ports/port/state/data-integrity/in-error-frames YANG schema element.

func (*Port_DataIntegrity_InErrorFramesPath) PathOriginName added in v0.14.1

func (n *Port_DataIntegrity_InErrorFramesPath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Port_DataIntegrity_InErrorFramesPath) State added in v0.14.1

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "in-error-frames"
Path from root:       "/ports/port/state/data-integrity/in-error-frames"

type Port_DataIntegrity_InErrorFramesPathAny added in v0.14.1

type Port_DataIntegrity_InErrorFramesPathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Port_DataIntegrity_InErrorFramesPathAny represents the wildcard version of the /open-traffic-generator-port/ports/port/state/data-integrity/in-error-frames YANG schema element.

func (*Port_DataIntegrity_InErrorFramesPathAny) State added in v0.14.1

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "in-error-frames"
Path from root:       "/ports/port/state/data-integrity/in-error-frames"

type Port_DataIntegrity_InTotalFramesPath added in v0.14.1

type Port_DataIntegrity_InTotalFramesPath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Port_DataIntegrity_InTotalFramesPath represents the /open-traffic-generator-port/ports/port/state/data-integrity/in-total-frames YANG schema element.

func (*Port_DataIntegrity_InTotalFramesPath) PathOriginName added in v0.14.1

func (n *Port_DataIntegrity_InTotalFramesPath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Port_DataIntegrity_InTotalFramesPath) State added in v0.14.1

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "in-total-frames"
Path from root:       "/ports/port/state/data-integrity/in-total-frames"

type Port_DataIntegrity_InTotalFramesPathAny added in v0.14.1

type Port_DataIntegrity_InTotalFramesPathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Port_DataIntegrity_InTotalFramesPathAny represents the wildcard version of the /open-traffic-generator-port/ports/port/state/data-integrity/in-total-frames YANG schema element.

func (*Port_DataIntegrity_InTotalFramesPathAny) State added in v0.14.1

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "in-total-frames"
Path from root:       "/ports/port/state/data-integrity/in-total-frames"

type Port_InRatePath

type Port_InRatePath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Port_InRatePath represents the /open-traffic-generator-port/ports/port/state/in-rate YANG schema element.

func (*Port_InRatePath) PathOriginName added in v0.14.0

func (n *Port_InRatePath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Port_InRatePath) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "state/in-rate"
Path from root:       "/ports/port/state/in-rate"

type Port_InRatePathAny

type Port_InRatePathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Port_InRatePathAny represents the wildcard version of the /open-traffic-generator-port/ports/port/state/in-rate YANG schema element.

func (*Port_InRatePathAny) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "state/in-rate"
Path from root:       "/ports/port/state/in-rate"

type Port_LastChangePath added in v0.7.1

type Port_LastChangePath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Port_LastChangePath represents the /open-traffic-generator-port/ports/port/state/last-change YANG schema element.

func (*Port_LastChangePath) PathOriginName added in v0.14.0

func (n *Port_LastChangePath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Port_LastChangePath) State added in v0.7.1

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "state/last-change"
Path from root:       "/ports/port/state/last-change"

type Port_LastChangePathAny added in v0.7.1

type Port_LastChangePathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Port_LastChangePathAny represents the wildcard version of the /open-traffic-generator-port/ports/port/state/last-change YANG schema element.

func (*Port_LastChangePathAny) State added in v0.7.1

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "state/last-change"
Path from root:       "/ports/port/state/last-change"

type Port_LinkPath

type Port_LinkPath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Port_LinkPath represents the /open-traffic-generator-port/ports/port/state/link YANG schema element.

func (*Port_LinkPath) PathOriginName added in v0.14.0

func (n *Port_LinkPath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Port_LinkPath) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "state/link"
Path from root:       "/ports/port/state/link"

type Port_LinkPathAny

type Port_LinkPathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Port_LinkPathAny represents the wildcard version of the /open-traffic-generator-port/ports/port/state/link YANG schema element.

func (*Port_LinkPathAny) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "state/link"
Path from root:       "/ports/port/state/link"

type Port_NamePath

type Port_NamePath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Port_NamePath represents the /open-traffic-generator-port/ports/port/state/name YANG schema element.

func (*Port_NamePath) Config

func (n *Port_NamePath) Config() ygnmi.ConfigQuery[string]

Config returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "name"
Path from root:       ""

func (*Port_NamePath) PathOriginName added in v0.14.0

func (n *Port_NamePath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Port_NamePath) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "state/name"
Path from root:       "/ports/port/state/name"

type Port_NamePathAny

type Port_NamePathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Port_NamePathAny represents the wildcard version of the /open-traffic-generator-port/ports/port/state/name YANG schema element.

func (*Port_NamePathAny) Config

Config returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "name"
Path from root:       ""

func (*Port_NamePathAny) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "state/name"
Path from root:       "/ports/port/state/name"

type Port_OutRatePath

type Port_OutRatePath struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Port_OutRatePath represents the /open-traffic-generator-port/ports/port/state/out-rate YANG schema element.

func (*Port_OutRatePath) PathOriginName added in v0.14.0

func (n *Port_OutRatePath) PathOriginName() string

PathOrigin returns the name of the origin for the path object.

func (*Port_OutRatePath) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "state/out-rate"
Path from root:       "/ports/port/state/out-rate"

type Port_OutRatePathAny

type Port_OutRatePathAny struct {
	*ygnmi.NodePath
	// contains filtered or unexported fields
}

Port_OutRatePathAny represents the wildcard version of the /open-traffic-generator-port/ports/port/state/out-rate YANG schema element.

func (*Port_OutRatePathAny) State

State returns a Query that can be used in gNMI operations.

Defining module:      "open-traffic-generator-port"
Instantiating module: "open-traffic-generator-port"
Path from parent:     "state/out-rate"
Path from root:       "/ports/port/state/out-rate"

Jump to