Documentation
¶
Overview ¶
Package dhcpv4client is a generated package which contains definitions of structs which generate gNMI paths for a YANG schema.
This package was generated by ygnmi version: v0.14.0: (ygot: v0.34.0) using the following YANG input files:
- models-yang/models/bgp/open-traffic-generator-bgp.yang
- models-yang/models/bmp-server/open-traffic-generator-bmp-server.yang
- models-yang/models/dhcp/v4client/open-traffic-generator-dhcpv4client.yang
- models-yang/models/dhcp/v4server/open-traffic-generator-dhcpv4server.yang
- models-yang/models/dhcp/v6client/open-traffic-generator-dhcpv6client.yang
- models-yang/models/dhcp/v6server/open-traffic-generator-dhcpv6server.yang
- models-yang/models/discovery/open-traffic-generator-discovery-interfaces.yang
- models-yang/models/discovery/open-traffic-generator-discovery.yang
- models-yang/models/flow/open-traffic-generator-flow.yang
- models-yang/models/interface/open-traffic-generator-port.yang
- models-yang/models/isis/open-traffic-generator-isis.yang
- models-yang/models/lacp/open-traffic-generator-lacp.yang
- models-yang/models/lag/open-traffic-generator-lag.yang
- models-yang/models/lldp/open-traffic-generator-lldp.yang
- models-yang/models/ospfv2/open-traffic-generator-ospfv2.yang
- models-yang/models/ospfv3/open-traffic-generator-ospfv3.yang
- models-yang/models/platform/open-traffic-generator-platform.yang
- models-yang/models/rsvp/open-traffic-generator-rsvp.yang
- models-yang/models/types/open-traffic-generator-types.yang
Imported modules were sourced from:
- models-yang/models/...
Index ¶
- type Dhcpv4ClientPath
- func (n *Dhcpv4ClientPath) Counters() *Dhcpv4Client_CountersPath
- func (n *Dhcpv4ClientPath) Interface() *Dhcpv4Client_InterfacePath
- func (n *Dhcpv4ClientPath) Name() *Dhcpv4Client_NamePath
- func (n *Dhcpv4ClientPath) PathOriginName() string
- func (n *Dhcpv4ClientPath) State() ygnmi.SingletonQuery[*oc.Dhcpv4Client]
- type Dhcpv4ClientPathAny
- type Dhcpv4ClientPathMap
- type Dhcpv4ClientPathMapAny
- type Dhcpv4Client_CountersPath
- func (n *Dhcpv4Client_CountersPath) AcksReceived() *Dhcpv4Client_Counters_AcksReceivedPath
- func (n *Dhcpv4Client_CountersPath) DeclinesSent() *Dhcpv4Client_Counters_DeclinesSentPath
- func (n *Dhcpv4Client_CountersPath) DiscoversSent() *Dhcpv4Client_Counters_DiscoversSentPath
- func (n *Dhcpv4Client_CountersPath) NacksReceived() *Dhcpv4Client_Counters_NacksReceivedPath
- func (n *Dhcpv4Client_CountersPath) OffersReceived() *Dhcpv4Client_Counters_OffersReceivedPath
- func (n *Dhcpv4Client_CountersPath) PathOriginName() string
- func (n *Dhcpv4Client_CountersPath) ReleasesSent() *Dhcpv4Client_Counters_ReleasesSentPath
- func (n *Dhcpv4Client_CountersPath) RequestsSent() *Dhcpv4Client_Counters_RequestsSentPath
- func (n *Dhcpv4Client_CountersPath) State() ygnmi.SingletonQuery[*oc.Dhcpv4Client_Counters]
- type Dhcpv4Client_CountersPathAny
- func (n *Dhcpv4Client_CountersPathAny) AcksReceived() *Dhcpv4Client_Counters_AcksReceivedPathAny
- func (n *Dhcpv4Client_CountersPathAny) DeclinesSent() *Dhcpv4Client_Counters_DeclinesSentPathAny
- func (n *Dhcpv4Client_CountersPathAny) DiscoversSent() *Dhcpv4Client_Counters_DiscoversSentPathAny
- func (n *Dhcpv4Client_CountersPathAny) NacksReceived() *Dhcpv4Client_Counters_NacksReceivedPathAny
- func (n *Dhcpv4Client_CountersPathAny) OffersReceived() *Dhcpv4Client_Counters_OffersReceivedPathAny
- func (n *Dhcpv4Client_CountersPathAny) ReleasesSent() *Dhcpv4Client_Counters_ReleasesSentPathAny
- func (n *Dhcpv4Client_CountersPathAny) RequestsSent() *Dhcpv4Client_Counters_RequestsSentPathAny
- func (n *Dhcpv4Client_CountersPathAny) State() ygnmi.WildcardQuery[*oc.Dhcpv4Client_Counters]
- type Dhcpv4Client_Counters_AcksReceivedPath
- type Dhcpv4Client_Counters_AcksReceivedPathAny
- type Dhcpv4Client_Counters_DeclinesSentPath
- type Dhcpv4Client_Counters_DeclinesSentPathAny
- type Dhcpv4Client_Counters_DiscoversSentPath
- type Dhcpv4Client_Counters_DiscoversSentPathAny
- type Dhcpv4Client_Counters_NacksReceivedPath
- type Dhcpv4Client_Counters_NacksReceivedPathAny
- type Dhcpv4Client_Counters_OffersReceivedPath
- type Dhcpv4Client_Counters_OffersReceivedPathAny
- type Dhcpv4Client_Counters_ReleasesSentPath
- type Dhcpv4Client_Counters_ReleasesSentPathAny
- type Dhcpv4Client_Counters_RequestsSentPath
- type Dhcpv4Client_Counters_RequestsSentPathAny
- type Dhcpv4Client_InterfacePath
- func (n *Dhcpv4Client_InterfacePath) Address() *Dhcpv4Client_Interface_AddressPath
- func (n *Dhcpv4Client_InterfacePath) GatewayAddress() *Dhcpv4Client_Interface_GatewayAddressPath
- func (n *Dhcpv4Client_InterfacePath) LeaseTime() *Dhcpv4Client_Interface_LeaseTimePath
- func (n *Dhcpv4Client_InterfacePath) PathOriginName() string
- func (n *Dhcpv4Client_InterfacePath) PrefixLength() *Dhcpv4Client_Interface_PrefixLengthPath
- func (n *Dhcpv4Client_InterfacePath) RebindTime() *Dhcpv4Client_Interface_RebindTimePath
- func (n *Dhcpv4Client_InterfacePath) RenewTime() *Dhcpv4Client_Interface_RenewTimePath
- func (n *Dhcpv4Client_InterfacePath) State() ygnmi.SingletonQuery[*oc.Dhcpv4Client_Interface]
- type Dhcpv4Client_InterfacePathAny
- func (n *Dhcpv4Client_InterfacePathAny) Address() *Dhcpv4Client_Interface_AddressPathAny
- func (n *Dhcpv4Client_InterfacePathAny) GatewayAddress() *Dhcpv4Client_Interface_GatewayAddressPathAny
- func (n *Dhcpv4Client_InterfacePathAny) LeaseTime() *Dhcpv4Client_Interface_LeaseTimePathAny
- func (n *Dhcpv4Client_InterfacePathAny) PrefixLength() *Dhcpv4Client_Interface_PrefixLengthPathAny
- func (n *Dhcpv4Client_InterfacePathAny) RebindTime() *Dhcpv4Client_Interface_RebindTimePathAny
- func (n *Dhcpv4Client_InterfacePathAny) RenewTime() *Dhcpv4Client_Interface_RenewTimePathAny
- func (n *Dhcpv4Client_InterfacePathAny) State() ygnmi.WildcardQuery[*oc.Dhcpv4Client_Interface]
- type Dhcpv4Client_Interface_AddressPath
- type Dhcpv4Client_Interface_AddressPathAny
- type Dhcpv4Client_Interface_GatewayAddressPath
- type Dhcpv4Client_Interface_GatewayAddressPathAny
- type Dhcpv4Client_Interface_LeaseTimePath
- type Dhcpv4Client_Interface_LeaseTimePathAny
- type Dhcpv4Client_Interface_PrefixLengthPath
- type Dhcpv4Client_Interface_PrefixLengthPathAny
- type Dhcpv4Client_Interface_RebindTimePath
- type Dhcpv4Client_Interface_RebindTimePathAny
- type Dhcpv4Client_Interface_RenewTimePath
- type Dhcpv4Client_Interface_RenewTimePathAny
- type Dhcpv4Client_NamePath
- type Dhcpv4Client_NamePathAny
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Dhcpv4ClientPath ¶
Dhcpv4ClientPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client YANG schema element.
func (*Dhcpv4ClientPath) Counters ¶
func (n *Dhcpv4ClientPath) Counters() *Dhcpv4Client_CountersPath
Counters (container): Counters of an indivdual DHCPv4 session.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "state/counters" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters"
func (*Dhcpv4ClientPath) Interface ¶
func (n *Dhcpv4ClientPath) Interface() *Dhcpv4Client_InterfacePath
Interface (container): Information about address learned by an indivdual DHCPv4 session.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "state/interface" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface"
func (*Dhcpv4ClientPath) Name ¶
func (n *Dhcpv4ClientPath) Name() *Dhcpv4Client_NamePath
Name (leaf): An arbitrary name of the DHCPv4 Client determined by the OTG configuration.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "*/name" Path from root: "/dhcpv4-clients/dhcpv4-client/*/name"
func (*Dhcpv4ClientPath) PathOriginName ¶ added in v0.14.0
func (n *Dhcpv4ClientPath) PathOriginName() string
PathOrigin returns the name of the origin for the path object.
func (*Dhcpv4ClientPath) State ¶
func (n *Dhcpv4ClientPath) State() ygnmi.SingletonQuery[*oc.Dhcpv4Client]
State returns a Query that can be used in gNMI operations.
type Dhcpv4ClientPathAny ¶
Dhcpv4ClientPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client YANG schema element.
func (*Dhcpv4ClientPathAny) Counters ¶
func (n *Dhcpv4ClientPathAny) Counters() *Dhcpv4Client_CountersPathAny
Counters (container): Counters of an indivdual DHCPv4 session.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "state/counters" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters"
func (*Dhcpv4ClientPathAny) Interface ¶
func (n *Dhcpv4ClientPathAny) Interface() *Dhcpv4Client_InterfacePathAny
Interface (container): Information about address learned by an indivdual DHCPv4 session.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "state/interface" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface"
func (*Dhcpv4ClientPathAny) Name ¶
func (n *Dhcpv4ClientPathAny) Name() *Dhcpv4Client_NamePathAny
Name (leaf): An arbitrary name of the DHCPv4 Client determined by the OTG configuration.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "*/name" Path from root: "/dhcpv4-clients/dhcpv4-client/*/name"
func (*Dhcpv4ClientPathAny) State ¶
func (n *Dhcpv4ClientPathAny) State() ygnmi.WildcardQuery[*oc.Dhcpv4Client]
State returns a Query that can be used in gNMI operations.
type Dhcpv4ClientPathMap ¶
Dhcpv4ClientPathMap represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client YANG schema element.
func (*Dhcpv4ClientPathMap) PathOriginName ¶ added in v0.14.0
func (n *Dhcpv4ClientPathMap) PathOriginName() string
PathOrigin returns the name of the origin for the path object.
type Dhcpv4ClientPathMapAny ¶
Dhcpv4ClientPathMapAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client YANG schema element.
type Dhcpv4Client_CountersPath ¶
Dhcpv4Client_CountersPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters YANG schema element.
func (*Dhcpv4Client_CountersPath) AcksReceived ¶
func (n *Dhcpv4Client_CountersPath) AcksReceived() *Dhcpv4Client_Counters_AcksReceivedPath
AcksReceived (leaf): Number of DHCPACKS messages received.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "acks-received" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/acks-received"
func (*Dhcpv4Client_CountersPath) DeclinesSent ¶
func (n *Dhcpv4Client_CountersPath) DeclinesSent() *Dhcpv4Client_Counters_DeclinesSentPath
DeclinesSent (leaf): Number of DHCPDECLINE messages sent.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "declines-sent" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/declines-sent"
func (*Dhcpv4Client_CountersPath) DiscoversSent ¶
func (n *Dhcpv4Client_CountersPath) DiscoversSent() *Dhcpv4Client_Counters_DiscoversSentPath
DiscoversSent (leaf): Number of DHCPDISCOVER messages sent.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "discovers-sent" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/discovers-sent"
func (*Dhcpv4Client_CountersPath) NacksReceived ¶
func (n *Dhcpv4Client_CountersPath) NacksReceived() *Dhcpv4Client_Counters_NacksReceivedPath
NacksReceived (leaf): Number of DHCPNACKS messages received.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "nacks-received" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/nacks-received"
func (*Dhcpv4Client_CountersPath) OffersReceived ¶
func (n *Dhcpv4Client_CountersPath) OffersReceived() *Dhcpv4Client_Counters_OffersReceivedPath
OffersReceived (leaf): Number of DHCPOFFER messages received.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "offers-received" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/offers-received"
func (*Dhcpv4Client_CountersPath) PathOriginName ¶ added in v0.14.0
func (n *Dhcpv4Client_CountersPath) PathOriginName() string
PathOrigin returns the name of the origin for the path object.
func (*Dhcpv4Client_CountersPath) ReleasesSent ¶
func (n *Dhcpv4Client_CountersPath) ReleasesSent() *Dhcpv4Client_Counters_ReleasesSentPath
ReleasesSent (leaf): Number of DHCPRELEASE messages sent.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "releases-sent" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/releases-sent"
func (*Dhcpv4Client_CountersPath) RequestsSent ¶
func (n *Dhcpv4Client_CountersPath) RequestsSent() *Dhcpv4Client_Counters_RequestsSentPath
RequestsSent (leaf): Number of DHCPREQUEST messages sent.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "requests-sent" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/requests-sent"
func (*Dhcpv4Client_CountersPath) State ¶
func (n *Dhcpv4Client_CountersPath) State() ygnmi.SingletonQuery[*oc.Dhcpv4Client_Counters]
State returns a Query that can be used in gNMI operations.
type Dhcpv4Client_CountersPathAny ¶
Dhcpv4Client_CountersPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters YANG schema element.
func (*Dhcpv4Client_CountersPathAny) AcksReceived ¶
func (n *Dhcpv4Client_CountersPathAny) AcksReceived() *Dhcpv4Client_Counters_AcksReceivedPathAny
AcksReceived (leaf): Number of DHCPACKS messages received.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "acks-received" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/acks-received"
func (*Dhcpv4Client_CountersPathAny) DeclinesSent ¶
func (n *Dhcpv4Client_CountersPathAny) DeclinesSent() *Dhcpv4Client_Counters_DeclinesSentPathAny
DeclinesSent (leaf): Number of DHCPDECLINE messages sent.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "declines-sent" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/declines-sent"
func (*Dhcpv4Client_CountersPathAny) DiscoversSent ¶
func (n *Dhcpv4Client_CountersPathAny) DiscoversSent() *Dhcpv4Client_Counters_DiscoversSentPathAny
DiscoversSent (leaf): Number of DHCPDISCOVER messages sent.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "discovers-sent" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/discovers-sent"
func (*Dhcpv4Client_CountersPathAny) NacksReceived ¶
func (n *Dhcpv4Client_CountersPathAny) NacksReceived() *Dhcpv4Client_Counters_NacksReceivedPathAny
NacksReceived (leaf): Number of DHCPNACKS messages received.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "nacks-received" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/nacks-received"
func (*Dhcpv4Client_CountersPathAny) OffersReceived ¶
func (n *Dhcpv4Client_CountersPathAny) OffersReceived() *Dhcpv4Client_Counters_OffersReceivedPathAny
OffersReceived (leaf): Number of DHCPOFFER messages received.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "offers-received" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/offers-received"
func (*Dhcpv4Client_CountersPathAny) ReleasesSent ¶
func (n *Dhcpv4Client_CountersPathAny) ReleasesSent() *Dhcpv4Client_Counters_ReleasesSentPathAny
ReleasesSent (leaf): Number of DHCPRELEASE messages sent.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "releases-sent" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/releases-sent"
func (*Dhcpv4Client_CountersPathAny) RequestsSent ¶
func (n *Dhcpv4Client_CountersPathAny) RequestsSent() *Dhcpv4Client_Counters_RequestsSentPathAny
RequestsSent (leaf): Number of DHCPREQUEST messages sent.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "requests-sent" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/requests-sent"
func (*Dhcpv4Client_CountersPathAny) State ¶
func (n *Dhcpv4Client_CountersPathAny) State() ygnmi.WildcardQuery[*oc.Dhcpv4Client_Counters]
State returns a Query that can be used in gNMI operations.
type Dhcpv4Client_Counters_AcksReceivedPath ¶
type Dhcpv4Client_Counters_AcksReceivedPath struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Counters_AcksReceivedPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/acks-received YANG schema element.
func (*Dhcpv4Client_Counters_AcksReceivedPath) PathOriginName ¶ added in v0.14.0
func (n *Dhcpv4Client_Counters_AcksReceivedPath) PathOriginName() string
PathOrigin returns the name of the origin for the path object.
func (*Dhcpv4Client_Counters_AcksReceivedPath) State ¶
func (n *Dhcpv4Client_Counters_AcksReceivedPath) State() ygnmi.SingletonQuery[uint64]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "acks-received" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/acks-received"
type Dhcpv4Client_Counters_AcksReceivedPathAny ¶
type Dhcpv4Client_Counters_AcksReceivedPathAny struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Counters_AcksReceivedPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/acks-received YANG schema element.
func (*Dhcpv4Client_Counters_AcksReceivedPathAny) State ¶
func (n *Dhcpv4Client_Counters_AcksReceivedPathAny) State() ygnmi.WildcardQuery[uint64]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "acks-received" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/acks-received"
type Dhcpv4Client_Counters_DeclinesSentPath ¶
type Dhcpv4Client_Counters_DeclinesSentPath struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Counters_DeclinesSentPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/declines-sent YANG schema element.
func (*Dhcpv4Client_Counters_DeclinesSentPath) PathOriginName ¶ added in v0.14.0
func (n *Dhcpv4Client_Counters_DeclinesSentPath) PathOriginName() string
PathOrigin returns the name of the origin for the path object.
func (*Dhcpv4Client_Counters_DeclinesSentPath) State ¶
func (n *Dhcpv4Client_Counters_DeclinesSentPath) State() ygnmi.SingletonQuery[uint64]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "declines-sent" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/declines-sent"
type Dhcpv4Client_Counters_DeclinesSentPathAny ¶
type Dhcpv4Client_Counters_DeclinesSentPathAny struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Counters_DeclinesSentPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/declines-sent YANG schema element.
func (*Dhcpv4Client_Counters_DeclinesSentPathAny) State ¶
func (n *Dhcpv4Client_Counters_DeclinesSentPathAny) State() ygnmi.WildcardQuery[uint64]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "declines-sent" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/declines-sent"
type Dhcpv4Client_Counters_DiscoversSentPath ¶
type Dhcpv4Client_Counters_DiscoversSentPath struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Counters_DiscoversSentPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/discovers-sent YANG schema element.
func (*Dhcpv4Client_Counters_DiscoversSentPath) PathOriginName ¶ added in v0.14.0
func (n *Dhcpv4Client_Counters_DiscoversSentPath) PathOriginName() string
PathOrigin returns the name of the origin for the path object.
func (*Dhcpv4Client_Counters_DiscoversSentPath) State ¶
func (n *Dhcpv4Client_Counters_DiscoversSentPath) State() ygnmi.SingletonQuery[uint64]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "discovers-sent" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/discovers-sent"
type Dhcpv4Client_Counters_DiscoversSentPathAny ¶
type Dhcpv4Client_Counters_DiscoversSentPathAny struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Counters_DiscoversSentPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/discovers-sent YANG schema element.
func (*Dhcpv4Client_Counters_DiscoversSentPathAny) State ¶
func (n *Dhcpv4Client_Counters_DiscoversSentPathAny) State() ygnmi.WildcardQuery[uint64]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "discovers-sent" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/discovers-sent"
type Dhcpv4Client_Counters_NacksReceivedPath ¶
type Dhcpv4Client_Counters_NacksReceivedPath struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Counters_NacksReceivedPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/nacks-received YANG schema element.
func (*Dhcpv4Client_Counters_NacksReceivedPath) PathOriginName ¶ added in v0.14.0
func (n *Dhcpv4Client_Counters_NacksReceivedPath) PathOriginName() string
PathOrigin returns the name of the origin for the path object.
func (*Dhcpv4Client_Counters_NacksReceivedPath) State ¶
func (n *Dhcpv4Client_Counters_NacksReceivedPath) State() ygnmi.SingletonQuery[uint64]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "nacks-received" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/nacks-received"
type Dhcpv4Client_Counters_NacksReceivedPathAny ¶
type Dhcpv4Client_Counters_NacksReceivedPathAny struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Counters_NacksReceivedPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/nacks-received YANG schema element.
func (*Dhcpv4Client_Counters_NacksReceivedPathAny) State ¶
func (n *Dhcpv4Client_Counters_NacksReceivedPathAny) State() ygnmi.WildcardQuery[uint64]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "nacks-received" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/nacks-received"
type Dhcpv4Client_Counters_OffersReceivedPath ¶
type Dhcpv4Client_Counters_OffersReceivedPath struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Counters_OffersReceivedPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/offers-received YANG schema element.
func (*Dhcpv4Client_Counters_OffersReceivedPath) PathOriginName ¶ added in v0.14.0
func (n *Dhcpv4Client_Counters_OffersReceivedPath) PathOriginName() string
PathOrigin returns the name of the origin for the path object.
func (*Dhcpv4Client_Counters_OffersReceivedPath) State ¶
func (n *Dhcpv4Client_Counters_OffersReceivedPath) State() ygnmi.SingletonQuery[uint64]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "offers-received" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/offers-received"
type Dhcpv4Client_Counters_OffersReceivedPathAny ¶
type Dhcpv4Client_Counters_OffersReceivedPathAny struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Counters_OffersReceivedPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/offers-received YANG schema element.
func (*Dhcpv4Client_Counters_OffersReceivedPathAny) State ¶
func (n *Dhcpv4Client_Counters_OffersReceivedPathAny) State() ygnmi.WildcardQuery[uint64]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "offers-received" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/offers-received"
type Dhcpv4Client_Counters_ReleasesSentPath ¶
type Dhcpv4Client_Counters_ReleasesSentPath struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Counters_ReleasesSentPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/releases-sent YANG schema element.
func (*Dhcpv4Client_Counters_ReleasesSentPath) PathOriginName ¶ added in v0.14.0
func (n *Dhcpv4Client_Counters_ReleasesSentPath) PathOriginName() string
PathOrigin returns the name of the origin for the path object.
func (*Dhcpv4Client_Counters_ReleasesSentPath) State ¶
func (n *Dhcpv4Client_Counters_ReleasesSentPath) State() ygnmi.SingletonQuery[uint64]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "releases-sent" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/releases-sent"
type Dhcpv4Client_Counters_ReleasesSentPathAny ¶
type Dhcpv4Client_Counters_ReleasesSentPathAny struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Counters_ReleasesSentPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/releases-sent YANG schema element.
func (*Dhcpv4Client_Counters_ReleasesSentPathAny) State ¶
func (n *Dhcpv4Client_Counters_ReleasesSentPathAny) State() ygnmi.WildcardQuery[uint64]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "releases-sent" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/releases-sent"
type Dhcpv4Client_Counters_RequestsSentPath ¶
type Dhcpv4Client_Counters_RequestsSentPath struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Counters_RequestsSentPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/requests-sent YANG schema element.
func (*Dhcpv4Client_Counters_RequestsSentPath) PathOriginName ¶ added in v0.14.0
func (n *Dhcpv4Client_Counters_RequestsSentPath) PathOriginName() string
PathOrigin returns the name of the origin for the path object.
func (*Dhcpv4Client_Counters_RequestsSentPath) State ¶
func (n *Dhcpv4Client_Counters_RequestsSentPath) State() ygnmi.SingletonQuery[uint64]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "requests-sent" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/requests-sent"
type Dhcpv4Client_Counters_RequestsSentPathAny ¶
type Dhcpv4Client_Counters_RequestsSentPathAny struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Counters_RequestsSentPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/counters/requests-sent YANG schema element.
func (*Dhcpv4Client_Counters_RequestsSentPathAny) State ¶
func (n *Dhcpv4Client_Counters_RequestsSentPathAny) State() ygnmi.WildcardQuery[uint64]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "requests-sent" Path from root: "/dhcpv4-clients/dhcpv4-client/state/counters/requests-sent"
type Dhcpv4Client_InterfacePath ¶
Dhcpv4Client_InterfacePath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface YANG schema element.
func (*Dhcpv4Client_InterfacePath) Address ¶
func (n *Dhcpv4Client_InterfacePath) Address() *Dhcpv4Client_Interface_AddressPath
Address (leaf): The IPv4 address associated with this DHCP Client session.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "address" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/address"
func (*Dhcpv4Client_InterfacePath) GatewayAddress ¶
func (n *Dhcpv4Client_InterfacePath) GatewayAddress() *Dhcpv4Client_Interface_GatewayAddressPath
GatewayAddress (leaf): The Gateway address associated with the DHCP Client session.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "gateway_address" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/gateway_address"
func (*Dhcpv4Client_InterfacePath) LeaseTime ¶
func (n *Dhcpv4Client_InterfacePath) LeaseTime() *Dhcpv4Client_Interface_LeaseTimePath
LeaseTime (leaf): The duration of the IP address lease, in seconds.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "lease_time" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/lease_time"
func (*Dhcpv4Client_InterfacePath) PathOriginName ¶ added in v0.14.0
func (n *Dhcpv4Client_InterfacePath) PathOriginName() string
PathOrigin returns the name of the origin for the path object.
func (*Dhcpv4Client_InterfacePath) PrefixLength ¶
func (n *Dhcpv4Client_InterfacePath) PrefixLength() *Dhcpv4Client_Interface_PrefixLengthPath
PrefixLength (leaf): The length of the prefix
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "prefix-length" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/prefix-length"
func (*Dhcpv4Client_InterfacePath) RebindTime ¶
func (n *Dhcpv4Client_InterfacePath) RebindTime() *Dhcpv4Client_Interface_RebindTimePath
RebindTime (leaf): Time in seconds until the DHCPv4 client starts rebinding.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "rebind_time" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/rebind_time"
func (*Dhcpv4Client_InterfacePath) RenewTime ¶
func (n *Dhcpv4Client_InterfacePath) RenewTime() *Dhcpv4Client_Interface_RenewTimePath
RenewTime (leaf): Time in seconds until the DHCPv4 client starts renewing the lease.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "renew_time" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/renew_time"
func (*Dhcpv4Client_InterfacePath) State ¶
func (n *Dhcpv4Client_InterfacePath) State() ygnmi.SingletonQuery[*oc.Dhcpv4Client_Interface]
State returns a Query that can be used in gNMI operations.
type Dhcpv4Client_InterfacePathAny ¶
Dhcpv4Client_InterfacePathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface YANG schema element.
func (*Dhcpv4Client_InterfacePathAny) Address ¶
func (n *Dhcpv4Client_InterfacePathAny) Address() *Dhcpv4Client_Interface_AddressPathAny
Address (leaf): The IPv4 address associated with this DHCP Client session.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "address" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/address"
func (*Dhcpv4Client_InterfacePathAny) GatewayAddress ¶
func (n *Dhcpv4Client_InterfacePathAny) GatewayAddress() *Dhcpv4Client_Interface_GatewayAddressPathAny
GatewayAddress (leaf): The Gateway address associated with the DHCP Client session.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "gateway_address" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/gateway_address"
func (*Dhcpv4Client_InterfacePathAny) LeaseTime ¶
func (n *Dhcpv4Client_InterfacePathAny) LeaseTime() *Dhcpv4Client_Interface_LeaseTimePathAny
LeaseTime (leaf): The duration of the IP address lease, in seconds.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "lease_time" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/lease_time"
func (*Dhcpv4Client_InterfacePathAny) PrefixLength ¶
func (n *Dhcpv4Client_InterfacePathAny) PrefixLength() *Dhcpv4Client_Interface_PrefixLengthPathAny
PrefixLength (leaf): The length of the prefix
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "prefix-length" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/prefix-length"
func (*Dhcpv4Client_InterfacePathAny) RebindTime ¶
func (n *Dhcpv4Client_InterfacePathAny) RebindTime() *Dhcpv4Client_Interface_RebindTimePathAny
RebindTime (leaf): Time in seconds until the DHCPv4 client starts rebinding.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "rebind_time" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/rebind_time"
func (*Dhcpv4Client_InterfacePathAny) RenewTime ¶
func (n *Dhcpv4Client_InterfacePathAny) RenewTime() *Dhcpv4Client_Interface_RenewTimePathAny
RenewTime (leaf): Time in seconds until the DHCPv4 client starts renewing the lease.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "renew_time" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/renew_time"
func (*Dhcpv4Client_InterfacePathAny) State ¶
func (n *Dhcpv4Client_InterfacePathAny) State() ygnmi.WildcardQuery[*oc.Dhcpv4Client_Interface]
State returns a Query that can be used in gNMI operations.
type Dhcpv4Client_Interface_AddressPath ¶
type Dhcpv4Client_Interface_AddressPath struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Interface_AddressPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/address YANG schema element.
func (*Dhcpv4Client_Interface_AddressPath) PathOriginName ¶ added in v0.14.0
func (n *Dhcpv4Client_Interface_AddressPath) PathOriginName() string
PathOrigin returns the name of the origin for the path object.
func (*Dhcpv4Client_Interface_AddressPath) State ¶
func (n *Dhcpv4Client_Interface_AddressPath) State() ygnmi.SingletonQuery[string]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "address" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/address"
type Dhcpv4Client_Interface_AddressPathAny ¶
type Dhcpv4Client_Interface_AddressPathAny struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Interface_AddressPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/address YANG schema element.
func (*Dhcpv4Client_Interface_AddressPathAny) State ¶
func (n *Dhcpv4Client_Interface_AddressPathAny) State() ygnmi.WildcardQuery[string]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "address" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/address"
type Dhcpv4Client_Interface_GatewayAddressPath ¶
type Dhcpv4Client_Interface_GatewayAddressPath struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Interface_GatewayAddressPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/gateway_address YANG schema element.
func (*Dhcpv4Client_Interface_GatewayAddressPath) PathOriginName ¶ added in v0.14.0
func (n *Dhcpv4Client_Interface_GatewayAddressPath) PathOriginName() string
PathOrigin returns the name of the origin for the path object.
func (*Dhcpv4Client_Interface_GatewayAddressPath) State ¶
func (n *Dhcpv4Client_Interface_GatewayAddressPath) State() ygnmi.SingletonQuery[string]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "gateway_address" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/gateway_address"
type Dhcpv4Client_Interface_GatewayAddressPathAny ¶
type Dhcpv4Client_Interface_GatewayAddressPathAny struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Interface_GatewayAddressPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/gateway_address YANG schema element.
func (*Dhcpv4Client_Interface_GatewayAddressPathAny) State ¶
func (n *Dhcpv4Client_Interface_GatewayAddressPathAny) State() ygnmi.WildcardQuery[string]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "gateway_address" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/gateway_address"
type Dhcpv4Client_Interface_LeaseTimePath ¶
type Dhcpv4Client_Interface_LeaseTimePath struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Interface_LeaseTimePath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/lease_time YANG schema element.
func (*Dhcpv4Client_Interface_LeaseTimePath) PathOriginName ¶ added in v0.14.0
func (n *Dhcpv4Client_Interface_LeaseTimePath) PathOriginName() string
PathOrigin returns the name of the origin for the path object.
func (*Dhcpv4Client_Interface_LeaseTimePath) State ¶
func (n *Dhcpv4Client_Interface_LeaseTimePath) State() ygnmi.SingletonQuery[uint32]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "lease_time" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/lease_time"
type Dhcpv4Client_Interface_LeaseTimePathAny ¶
type Dhcpv4Client_Interface_LeaseTimePathAny struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Interface_LeaseTimePathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/lease_time YANG schema element.
func (*Dhcpv4Client_Interface_LeaseTimePathAny) State ¶
func (n *Dhcpv4Client_Interface_LeaseTimePathAny) State() ygnmi.WildcardQuery[uint32]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "lease_time" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/lease_time"
type Dhcpv4Client_Interface_PrefixLengthPath ¶
type Dhcpv4Client_Interface_PrefixLengthPath struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Interface_PrefixLengthPath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/prefix-length YANG schema element.
func (*Dhcpv4Client_Interface_PrefixLengthPath) PathOriginName ¶ added in v0.14.0
func (n *Dhcpv4Client_Interface_PrefixLengthPath) PathOriginName() string
PathOrigin returns the name of the origin for the path object.
func (*Dhcpv4Client_Interface_PrefixLengthPath) State ¶
func (n *Dhcpv4Client_Interface_PrefixLengthPath) State() ygnmi.SingletonQuery[uint32]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "prefix-length" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/prefix-length"
type Dhcpv4Client_Interface_PrefixLengthPathAny ¶
type Dhcpv4Client_Interface_PrefixLengthPathAny struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Interface_PrefixLengthPathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/prefix-length YANG schema element.
func (*Dhcpv4Client_Interface_PrefixLengthPathAny) State ¶
func (n *Dhcpv4Client_Interface_PrefixLengthPathAny) State() ygnmi.WildcardQuery[uint32]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "prefix-length" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/prefix-length"
type Dhcpv4Client_Interface_RebindTimePath ¶
type Dhcpv4Client_Interface_RebindTimePath struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Interface_RebindTimePath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/rebind_time YANG schema element.
func (*Dhcpv4Client_Interface_RebindTimePath) PathOriginName ¶ added in v0.14.0
func (n *Dhcpv4Client_Interface_RebindTimePath) PathOriginName() string
PathOrigin returns the name of the origin for the path object.
func (*Dhcpv4Client_Interface_RebindTimePath) State ¶
func (n *Dhcpv4Client_Interface_RebindTimePath) State() ygnmi.SingletonQuery[uint32]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "rebind_time" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/rebind_time"
type Dhcpv4Client_Interface_RebindTimePathAny ¶
type Dhcpv4Client_Interface_RebindTimePathAny struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Interface_RebindTimePathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/rebind_time YANG schema element.
func (*Dhcpv4Client_Interface_RebindTimePathAny) State ¶
func (n *Dhcpv4Client_Interface_RebindTimePathAny) State() ygnmi.WildcardQuery[uint32]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "rebind_time" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/rebind_time"
type Dhcpv4Client_Interface_RenewTimePath ¶
type Dhcpv4Client_Interface_RenewTimePath struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Interface_RenewTimePath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/renew_time YANG schema element.
func (*Dhcpv4Client_Interface_RenewTimePath) PathOriginName ¶ added in v0.14.0
func (n *Dhcpv4Client_Interface_RenewTimePath) PathOriginName() string
PathOrigin returns the name of the origin for the path object.
func (*Dhcpv4Client_Interface_RenewTimePath) State ¶
func (n *Dhcpv4Client_Interface_RenewTimePath) State() ygnmi.SingletonQuery[uint32]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "renew_time" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/renew_time"
type Dhcpv4Client_Interface_RenewTimePathAny ¶
type Dhcpv4Client_Interface_RenewTimePathAny struct {
*ygnmi.NodePath
// contains filtered or unexported fields
}
Dhcpv4Client_Interface_RenewTimePathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/interface/renew_time YANG schema element.
func (*Dhcpv4Client_Interface_RenewTimePathAny) State ¶
func (n *Dhcpv4Client_Interface_RenewTimePathAny) State() ygnmi.WildcardQuery[uint32]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "renew_time" Path from root: "/dhcpv4-clients/dhcpv4-client/state/interface/renew_time"
type Dhcpv4Client_NamePath ¶
Dhcpv4Client_NamePath represents the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/name YANG schema element.
func (*Dhcpv4Client_NamePath) Config ¶
func (n *Dhcpv4Client_NamePath) Config() ygnmi.ConfigQuery[string]
Config returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "name" Path from root: ""
func (*Dhcpv4Client_NamePath) PathOriginName ¶ added in v0.14.0
func (n *Dhcpv4Client_NamePath) PathOriginName() string
PathOrigin returns the name of the origin for the path object.
func (*Dhcpv4Client_NamePath) State ¶
func (n *Dhcpv4Client_NamePath) State() ygnmi.SingletonQuery[string]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "state/name" Path from root: "/dhcpv4-clients/dhcpv4-client/state/name"
type Dhcpv4Client_NamePathAny ¶
Dhcpv4Client_NamePathAny represents the wildcard version of the /open-traffic-generator-dhcpv4client/dhcpv4-clients/dhcpv4-client/state/name YANG schema element.
func (*Dhcpv4Client_NamePathAny) Config ¶
func (n *Dhcpv4Client_NamePathAny) Config() ygnmi.WildcardQuery[string]
Config returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "name" Path from root: ""
func (*Dhcpv4Client_NamePathAny) State ¶
func (n *Dhcpv4Client_NamePathAny) State() ygnmi.WildcardQuery[string]
State returns a Query that can be used in gNMI operations.
Defining module: "open-traffic-generator-dhcpv4client" Instantiating module: "open-traffic-generator-dhcpv4client" Path from parent: "state/name" Path from root: "/dhcpv4-clients/dhcpv4-client/state/name"